summaryrefslogtreecommitdiffstats
path: root/browser/app/nsBrowserApp.cpp
diff options
context:
space:
mode:
authorMatt A. Tobin <email@mattatobin.com>2018-02-05 06:25:10 -0500
committerMatt A. Tobin <email@mattatobin.com>2018-02-05 06:25:10 -0500
commita1aed76b5f709e4139f0165f3614b89fa1d93f0d (patch)
tree6f8c6e416ace8a86fd684b1d3cfcd69b3fb15382 /browser/app/nsBrowserApp.cpp
parent2eef10791129874f6e04b446fbdbaa3b4ad61a60 (diff)
downloadUXP-a1aed76b5f709e4139f0165f3614b89fa1d93f0d.tar
UXP-a1aed76b5f709e4139f0165f3614b89fa1d93f0d.tar.gz
UXP-a1aed76b5f709e4139f0165f3614b89fa1d93f0d.tar.lz
UXP-a1aed76b5f709e4139f0165f3614b89fa1d93f0d.tar.xz
UXP-a1aed76b5f709e4139f0165f3614b89fa1d93f0d.zip
De-firefox many things
Diffstat (limited to 'browser/app/nsBrowserApp.cpp')
-rw-r--r--browser/app/nsBrowserApp.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/browser/app/nsBrowserApp.cpp b/browser/app/nsBrowserApp.cpp
index 981e2f14c..ac2e85ea3 100644
--- a/browser/app/nsBrowserApp.cpp
+++ b/browser/app/nsBrowserApp.cpp
@@ -25,7 +25,7 @@
#ifdef XP_WIN
#ifdef MOZ_ASAN
// ASAN requires firefox.exe to be built with -MD, and it's OK if we don't
// support Windows XP SP2 in ASAN builds.
#define XRE_DONT_SUPPORT_XPSP2
#endif
@@ -84,7 +84,7 @@ static void Output(const char *fmt, ... )
decltype(MessageBoxW)* messageBoxW =
(decltype(MessageBoxW)*) GetProcAddress(user32, "MessageBoxW");
if (messageBoxW) {
- messageBoxW(nullptr, wide_msg, L"Firefox", MB_OK
+ messageBoxW(nullptr, wide_msg, L"Basilisk", MB_OK
| MB_ICONERROR
| MB_SETFOREGROUND);
}
@@ -170,7 +170,7 @@ static int do_main(int argc, char* argv[], char* envp[], nsIFile *xreDirectory)
nsresult rv;
uint32_t mainFlags = 0;
// Allow firefox.exe to launch XULRunner apps via -app <application.ini>
// Note that -app must be the *first* argument.
const char *appDataFile = getenv("XUL_APP_FILE");
if (appDataFile && *appDataFile) {
@@ -25,7 +25,7 @@
#ifdef XP_WIN
#ifdef MOZ_ASAN
-// ASAN requires firefox.exe to be built with -MD, and it's OK if we don't
+// ASAN requires basilisk.exe to be built with -MD, and it's OK if we don't
// support Windows XP SP2 in ASAN builds.
#define XRE_DONT_SUPPORT_XPSP2
@@ -170,7 +170,7 @@ static int do_main(int argc, char* argv[], char* envp[], nsIFile *xreDirectory)
nsresult rv;
uint32_t mainFlags = 0;
- // Allow firefox.exe to launch XULRunner apps via -app <application.ini>
+ // Allow basilisk.exe to launch XULRunner apps via -app <application.ini>
// Note that -app must be the *first* argument.
const char *appDataFile = getenv("XUL_APP_FILE");